@@ -1,23 +1,12 @@
-/***************************************************************************
- *   KShisen - A japanese game similar to mahjongg                         *
- *   Copyright 1997  Mario Weilguni <mweilguni@sime.com>                   *
- *   Copyright 2002-2004  Dave Corrie <kde@davecorrie.com>                 *
- *   Copyright 2007  Mauricio Piacentini <mauricio@tabuleiro.com>          *
- *   Copyright 2009-2016  Frederik Schwarzer <schwarzer@kde.org>           *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program.  If not, see <http://www.gnu.org/licenses/>. *
- ***************************************************************************/
+/*
+    KShisen - A japanese game similar to Mahjongg
+    SPDX-FileCopyrightText: 1997 Mario Weilguni <mweilguni@sime.com>
+    SPDX-FileCopyrightText: 2002-2004 Dave Corrie <kde@davecorrie.com>
+    SPDX-FileCopyrightText: 2007 Mauricio Piacentini <mauricio@tabuleiro.com>
+    SPDX-FileCopyrightText: 2009-2016 Frederik Schwarzer <schwarzer@kde.org>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 // own
 #include "app.h"
@@ -32,7 +21,7 @@
 #include <QStatusBar>
 #include <QTimer>
 
-// KDE
+// KF
 #include <KActionCollection>
 #include <KConfig>
 #include <KConfigDialog>
@@ -47,7 +36,7 @@
 #include <KStandardGameAction>
 
 // LibKmahjongg
-#include <kmahjonggconfigdialog.h>
+#include <KMahjonggConfigDialog>
 
 // KShisen
 #include "board.h"
@@ -111,16 +100,16 @@ void App::setupStatusBar()
 void App::setupActions()
 {
     // Game
-    KStandardGameAction::gameNew(this, SIGNAL(invokeNewGame()), actionCollection());
-    KStandardGameAction::restart(this, SLOT(restartGame()), actionCollection());
-    KStandardGameAction::pause(this, SLOT(togglePause()), actionCollection());
-    KStandardGameAction::highscores(this, SLOT(showHighscores()), actionCollection());
-    KStandardGameAction::quit(this, SLOT(close()), actionCollection());
+    KStandardGameAction::gameNew(this, &App::invokeNewGame, actionCollection());
+    KStandardGameAction::restart(this, &App::restartGame, actionCollection());
+    KStandardGameAction::pause(this, &App::togglePause, actionCollection());
+    KStandardGameAction::highscores(this, &App::showHighscores, actionCollection());
+    KStandardGameAction::quit(this, &App::close, actionCollection());
 
     // Move
-    KStandardGameAction::undo(this, SLOT(undo()), actionCollection());
-    KStandardGameAction::redo(this, SLOT(redo()), actionCollection());
-    KStandardGameAction::hint(this, SLOT(hint()), actionCollection());
+    KStandardGameAction::undo(this, &App::undo, actionCollection());
+    KStandardGameAction::redo(this, &App::redo, actionCollection());
+    KStandardGameAction::hint(this, &App::hint, actionCollection());
 
     auto soundAction = new KToggleAction(QIcon::fromTheme(QStringLiteral("speaker")), i18n("Play Sounds"), this);
     soundAction->setChecked(Prefs::sounds());
@@ -128,7 +117,7 @@ void App::setupActions()
     connect(soundAction, &KToggleAction::triggered, m_board, &Board::setSoundsEnabled);
 
     // Settings
-    KStandardAction::preferences(this, SLOT(showSettingsDialog()), actionCollection());
+    KStandardAction::preferences(this, &App::showSettingsDialog, actionCollection());
 
     connect(m_board, &Board::cheatStatusChanged, this, &App::updateCheatDisplay);
     connect(m_board, &Board::changed, this, &App::updateItems);
